.. _apidocs:

Library API Docs
================

.. toctree::
   :maxdepth: 4
   :caption: Completed APIs

   hpecp.client
   hpecp.license
   hpecp.lock
   hpecp.gateway
   hpecp.base_resource

.. toctree::
   :maxdepth: 4
   :caption: Work-in-progress APIs

   hpecp.k8s_worker
   hpecp.k8s_cluster
   hpecp.config
   hpecp.tag
   hpecp.tenant
   hpecp.exceptions

CLI API Docs
================

 .. toctree::
   :maxdepth: 4

   cli 